asr.test.test\_database\_rmsd
=============================

.. automodule:: asr.test.test_database_rmsd

   
   
   .. rubric:: Functions

   
   .. autofunction:: rattle_atoms
   .. autofunction:: test_database_rmsd_duplicates
   .. autofunction:: test_database_rmsd_duplicates_comparison_keys
   .. autofunction:: test_database_rmsd_move_one_atom
   .. autofunction:: test_database_rmsd_none_handling
   .. autofunction:: test_database_rmsd_not_equal
   .. autofunction:: test_database_rmsd_rattled
   .. autofunction:: test_database_rmsd_rotation
   
   

   
   
   

   
   
   